@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2012                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 // Authentifie et si ok retourne le tableau de la ligne SQL de l'utilisateur
 // Si risque de secu repere a l'installation retourne False
@@ -18,6 +18,8 @@ function auth_spip_dist ($login, $pass, $serveur='') {
 
 	// retrouver le login
 	$login = auth_spip_retrouver_login($login);
+	// login inconnu, n'allons pas plus loin
+	if (!$login) return array();
 
 	$md5pass = $md5next = "";
 	$shapass = $shanext = "";
@@ -35,15 +37,15 @@ function auth_spip_dist ($login, $pass, $serveur='') {
 		$md5next = $regs[4];
 		$pass="";
 	}
-  // si envoi non crypte, crypter maintenant
+
+	// si envoi non crypte, crypter maintenant
 	elseif ($pass) {
 		$row = sql_fetsel("alea_actuel, alea_futur", "spip_auteurs", "login=" . sql_quote($login),'','','','',$serveur);
 
 		if ($row) {
-			//var_dump('pas la !');
 			include_spip('auth/sha256.inc');
-			$shapass = sha256($row['alea_actuel'] . $pass);
-			$shanext = sha256($row['alea_futur'] . $pass);
+			$shapass = _nano_sha256($row['alea_actuel'] . $pass);
+			$shanext = _nano_sha256($row['alea_futur'] . $pass);
 			$md5pass = md5($row['alea_actuel'] . $pass);
 		}
 	}
@@ -64,7 +66,7 @@ function auth_spip_dist ($login, $pass, $serveur='') {
 	if ($shanext) {
 
 		include_spip('inc/acces'); // pour creer_uniqid
-		@sql_update('spip_auteurs', array('alea_actuel' => 'alea_futur', 'pass' => sql_quote($shanext), 'alea_futur' => sql_quote(creer_uniqid())), "id_auteur=" . $row['id_auteur'],'',$serveur);
+		@sql_update('spip_auteurs', array('alea_actuel' => 'alea_futur', 'pass' => sql_quote($shanext), 'alea_futur' => sql_quote(creer_uniqid())), "id_auteur=" . $row['id_auteur'].' AND pass IN ('.sql_quote($shapass).', '.sql_quote($md5pass).')','',$serveur);
 		// En profiter pour verifier la securite de tmp/
 		// Si elle ne fonctionne pas a l'installation, prevenir
 		if (!verifier_htaccess(_DIR_TMP) AND defined('_ECRIRE_INSTALL'))
@@ -92,13 +94,13 @@ function auth_spip_formulaire_login($flux){
 		."var informe_auteur_en_cours = false;"
 		."var attente_informe = 0;"
 		."var compat_md5 = ".($compat_md5?"true;":"false;")
-		."(function($){
-		$('#password')
+		."jQuery(function(){
+		jQuery('#password')
 			.after(\"<em id='pass_securise'><img src='"._DIR_IMG_PACK."securise.gif' width='16' height='16' alt='" . attribut_html(_T('login_securise')) . "' title='" . attribut_html(_T('login_securise')) . "' \/><\/em>\");
 		affiche_login_secure();
-		$('#var_login').change(actualise_auteur);
-		$('form#formulaire_login').submit(login_submit);
-	}(jQuery));"
+		jQuery('#var_login').change(actualise_auteur);
+		jQuery('form#formulaire_login').submit(login_submit);
+	});"
 		."/*]]>*/</script>";
 
 	return $flux;
@@ -127,9 +129,9 @@ function auth_spip_autoriser_modifier_login($serveur=''){
  */
 function auth_spip_verifier_login($new_login, $id_auteur=0, $serveur=''){
 	// login et mot de passe
-	if (strlen($login)){
+	if (strlen($new_login)){
 		if (strlen($new_login) < _LOGIN_TROP_COURT)
-			return 'info_login_trop_court';
+			return _T('info_login_trop_court');
 		else {
 			$n = sql_countsel('spip_auteurs', "login=" . sql_quote($new_login) . " AND id_auteur!=".intval($id_auteur)." AND statut!='5poubelle'",'','',$serveur);
 			if ($n)
@@ -179,6 +181,7 @@ function auth_spip_modifier_login($new_login, $id_auteur, $serveur=''){
  * @return string
  */
 function auth_spip_retrouver_login($login, $serveur=''){
+	if (!strlen($login)) return null; // pas la peine de requeter
 	$l = sql_quote($login);
 	if ($r = sql_getfetsel('login', 'spip_auteurs',
 			"statut<>'5poubelle'" .
@@ -265,7 +268,7 @@ function auth_spip_modifier_pass($login, $new_pass, $id_auteur, $serveur=''){
 	$htpass = generer_htpass($new_pass);
 	$alea_actuel = creer_uniqid();
 	$alea_futur = creer_uniqid();
-	$pass = sha256($alea_actuel.$new_pass);
+	$pass = _nano_sha256($alea_actuel.$new_pass);
 	$c['pass'] = $pass;
 	$c['htpass'] = $htpass;
 	$c['alea_actuel'] = $alea_actuel;
