@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2012                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -11,7 +11,7 @@
 \***************************************************************************/
 
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 include_spip('inc/filtres'); // par precaution
 
 
@@ -117,8 +117,8 @@ function _image_valeurs_trans($img, $effet, $forcer_format = false, $fonction_cr
 	}
 
 	$terminaison_dest = "";
-	if (preg_match(",^(?>.*)(?<=\.(gif|jpg|png)),", $fichier, $regs)) {
-		$terminaison = $regs[1];
+	if (preg_match(",\.(gif|jpe?g|png)($|[?]),i", $fichier, $regs)) {
+		$terminaison = strtolower($regs[1]);
 		$terminaison_dest = $terminaison;
 		
 		if ($terminaison == "gif") $terminaison_dest = "png";
@@ -130,7 +130,7 @@ function _image_valeurs_trans($img, $effet, $forcer_format = false, $fonction_cr
 	$term_fonction = $terminaison;
 	if ($term_fonction == "jpg") $term_fonction = "jpeg";
 
-	$nom_fichier = substr($fichier, 0, strlen($fichier) - 4);
+	$nom_fichier = substr($fichier, 0, strlen($fichier) - (strlen($terminaison) + 1));
 	$fichier_dest = $nom_fichier;
 
 	if (@file_exists($f = $fichier)){
@@ -225,7 +225,7 @@ function _image_valeurs_trans($img, $effet, $forcer_format = false, $fonction_cr
 	$ret["fichier"] = $fichier;
 	$ret["fonction_image"] = "_image_image".$terminaison_dest;
 	$ret["fichier_dest"] = $fichier_dest;
-	$ret["format_source"] = $terminaison;
+	$ret["format_source"] = ($terminaison != 'jpeg' ? $terminaison : 'jpg');
 	$ret["format_dest"] = $terminaison_dest;
 	$ret["date_src"] = $date_src;
 	$ret["creer"] = $creer;
@@ -928,4 +928,4 @@ class phpthumb_functions {
 
 }
 
-?>
\ No newline at end of file
+?>
