@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -654,7 +654,6 @@ Gracies por participar
 'onglet_repartition_rubrique' => 'Repart&iacute;o por estayes',
 'onglet_save_restaur_base' => 'Sofitar/restaurar la base',
 'onglet_vider_cache' => 'Vaciar la cach&eacute;',
-'ortho_trop_de_fautes2' => 'Entama por iguar les faltes m&aacute;s evidentes y llu&eacute;u torna a intentalo.',
 
 // P
 'pass_choix_pass' => 'Escueye la nueva contrase&ntilde;a:',
