@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -561,7 +561,7 @@ Vielen Dank f&uuml;r Ihre Teilnahme
 'info_visites' => 'Besuche:',
 'info_vos_rendez_vous' => 'Ihre kommenden Termine',
 'info_zoom' => 'Zoom',
-'infos_vos_pense_bete' => 'Ihre Merkzettel', # MODIF
+'infos_vos_pense_bete' => 'Ihre Merkzettel',
 'item_breve_proposee' => 'Vorgeschlagene Meldung',
 
 // L
@@ -641,7 +641,6 @@ Vielen Dank f&uuml;r Ihre Teilnahme
 'onglet_repartition_rubrique' => 'Verteilung auf Rubriken',
 'onglet_save_restaur_base' => 'Datenbank sichern/wieder herstellen',
 'onglet_vider_cache' => 'Sitecache l&ouml;schen',
-'ortho_trop_de_fautes2' => 'Korrigieren sie zun&auml;chst die offensichtlichen Fehler und starten dann einen neuen Versuch.',
 
 // P
 'pass_choix_pass' => 'Bitte geben Sie Ihr neues Passwort ein:',
