@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -653,7 +653,6 @@ Dankon pro via partopreno
 'onglet_repartition_rubrique' => 'Distribuo la&#365; rubrikoj',
 'onglet_save_restaur_base' => 'Savkopii/resta&#365;ri la datenbazon',
 'onglet_vider_cache' => 'Malplenigi la staplon',
-'ortho_trop_de_fautes2' => 'Bonvolu korekti la plej evidentajn erarojn kaj poste reprovu.',
 
 // P
 'pass_choix_pass' => 'Bonvolu elekti vian novan pasvorton:',
