@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -647,7 +647,6 @@ sera ignor&eacute;e) :
 'onglet_repartition_rubrique' => '&#25353;&#19987;&#26639;&#21457;&#24067;',
 'onglet_save_restaur_base' => '&#22791;&#20221;/&#24674;&#22797;&#25968;&#25454;&#24211;',
 'onglet_vider_cache' => '&#28165;&#31354;&#32531;&#23384;',
-'ortho_trop_de_fautes2' => '&#35831;&#20462;&#25913;&#26368;&#26126;&#26174;&#30340;&#38169;&#35823;&#65292;&#28982;&#21518;&#20877;&#35797;&#12290;',
 
 // P
 'pass_choix_pass' => '&#35831;&#36873;&#25321;&#26032;&#23494;&#30721;:',
