@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2011                                                *
+ *  Copyright (c) 2001-2012                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -590,7 +590,7 @@ function balise_PARAMETRES_FORUM_dist($p) {
 	// pas de calculs superflus si le site est monolingue
 	$lang = strpos($GLOBALS['meta']['langues_utilisees'], ',');
 
-	switch ($p->type_requete) {
+	switch (!$p->id_boucle? '' : $p->boucles[$p->id_boucle]->type_requete) {
 		case 'articles':
 			$c = '"id_article=".' . champ_sql('id_article', $p);
 			if ($lang) $lang = champ_sql('lang', $p);
