@@ -3,23 +3,26 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2010                                                *
+ *  Copyright (c) 2001-2012                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 // fonction pour la premiere connexion a un serveur MySQL
 
 // http://doc.spip.org/@req_mysql_dist
 function req_mysql_dist($host, $port, $login, $pass, $db='', $prefixe='') {
-	charger_php_extension('mysql');
+	if (!charger_php_extension('mysql')) return false;
 	if ($port > 0) $host = "$host:$port";
 	$link = @mysql_connect($host, $login, $pass, true);
-	if (!$link) return false;
+	if (!$link) {
+		spip_log('Echec mysql_connect. Erreur : ' . mysql_error(),'mysql');
+		return false;
+	}
 	$last = '';
 	if (!$db) {
 		$ok = $link;
@@ -95,14 +98,14 @@ $GLOBALS['spip_mysql_functions_1'] = array(
 
 // http://doc.spip.org/@spip_mysql_set_charset
 function spip_mysql_set_charset($charset, $serveur='',$requeter=true,$requeter=true){
-	$connexion = &$GLOBALS['connexions'][$serveur ? $serveur : 0];
+	$connexion = &$GLOBALS['connexions'][$serveur ? strtolower($serveur) : 0];
 	#spip_log("changement de charset sql : "."SET NAMES "._q($charset));
 	return mysql_query($connexion['last'] = "SET NAMES "._q($charset));
 }
 
 // http://doc.spip.org/@spip_mysql_get_charset
 function spip_mysql_get_charset($charset=array(), $serveur='',$requeter=true){
-	$connexion = &$GLOBALS['connexions'][$serveur ? $serveur : 0];
+	$connexion = &$GLOBALS['connexions'][$serveur ? strtolower($serveur) : 0];
 	$connexion['last'] = $c = "SHOW CHARACTER SET"
 	. (!$charset ? '' : (" LIKE "._q($charset['charset'])));
 
@@ -120,7 +123,7 @@ function spip_query_db($query, $serveur='',$requeter=true) {
 // http://doc.spip.org/@spip_mysql_query
 function spip_mysql_query($query, $serveur='',$requeter=true) {
 
-	$connexion = &$GLOBALS['connexions'][$serveur ? $serveur : 0];
+	$connexion = &$GLOBALS['connexions'][$serveur ? strtolower($serveur) : 0];
 	$prefixe = $connexion['prefixe'];
 	$link = $connexion['link'];
 	$db = $connexion['db'];
@@ -138,7 +141,9 @@ function spip_mysql_query($query, $serveur='',$requeter=true) {
 	$connexion['last'] = $query;
 	$r = $link ? mysql_query($query, $link) : mysql_query($query);
 
-	return $t ? trace_query_end($query, $t, $r, $serveur) : $r;
+	if ($e = spip_mysql_errno($serveur))	// Log de l'erreur eventuelle
+		$e .= spip_mysql_error($query, $serveur); // et du fautif
+	return $t ? trace_query_end($query, $t, $r, $e, $serveur) : $r;
 }
 
 // http://doc.spip.org/@spip_mysql_alter
@@ -155,7 +160,7 @@ function spip_mysql_optimize($table, $serveur='',$requeter=true){
 // http://doc.spip.org/@spip_mysql_explain
 function spip_mysql_explain($query, $serveur='',$requeter=true){
 	if (strpos(ltrim($query), 'SELECT') !== 0) return array();
-	$connexion = &$GLOBALS['connexions'][$serveur ? $serveur : 0];
+	$connexion = &$GLOBALS['connexions'][$serveur ? strtolower($serveur) : 0];
 	$prefixe = $connexion['prefixe'];
 	$link = $connexion['link'];
 	$db = $connexion['db'];
@@ -297,7 +302,10 @@ function traite_query($query, $db='', $prefixe='') {
 
 // http://doc.spip.org/@spip_mysql_selectdb
 function spip_mysql_selectdb($db) {
-	return mysql_select_db($db);
+	$ok = mysql_select_db($db);
+	if (!$ok)
+		spip_log('Echec mysql_selectdb. Erreur : ' . mysql_error(),'mysql');
+	return $ok;
 }
 
 
@@ -306,7 +314,8 @@ function spip_mysql_selectdb($db) {
 
 // http://doc.spip.org/@spip_mysql_listdbs
 function spip_mysql_listdbs($serveur='',$requeter=true) {
-	return @mysql_list_dbs();
+	$res = spip_mysql_query("SHOW DATABASES");
+	return $res;
 }
 
 // Fonction de creation d'une table SQL nommee $nom
@@ -389,26 +398,26 @@ function spip_mysql_create_view($nom, $query_select, $serveur='',$requeter=true)
 function spip_mysql_drop_table($table, $exist='', $serveur='',$requeter=true)
 {
 	if ($exist) $exist =" IF EXISTS";
-	return spip_mysql_query("DROP TABLE$exist $table", $serveur, $requeter);
+	return spip_mysql_query("DROP TABLE$exist `$table`", $serveur, $requeter);
 }
 
 // supprime une vue 
 // http://doc.spip.org/@spip_mysql_drop_view
 function spip_mysql_drop_view($view, $exist='', $serveur='',$requeter=true) {
 	if ($exist) $exist =" IF EXISTS";
-	return spip_mysql_query("DROP VIEW$exist $view", $serveur, $requeter);
+	return spip_mysql_query("DROP VIEW$exist `$view`", $serveur, $requeter);
 }
 
 // http://doc.spip.org/@spip_mysql_showbase
 function spip_mysql_showbase($match, $serveur='',$requeter=true)
 {
-	return spip_mysql_query("SHOW TABLES LIKE '$match'", $serveur, $requeter);
+	return spip_mysql_query("SHOW TABLES LIKE " . _q($match), $serveur, $requeter);
 }
 
 // http://doc.spip.org/@spip_mysql_repair
 function spip_mysql_repair($table, $serveur='',$requeter=true)
 {
-	return spip_mysql_query("REPAIR TABLE $table", $serveur, $requeter);
+	return spip_mysql_query("REPAIR TABLE `$table`", $serveur, $requeter);
 }
 
 // Recupere la definition d'une table ou d'une vue MySQL
@@ -511,24 +520,26 @@ function spip_mysql_countsel($from = array(), $where = array(),
 	return $c;
 }
 
+// Bien specifier le serveur auquel on s'adresse,
+// mais a l'install la globale n'est pas encore completement definie
 // http://doc.spip.org/@spip_mysql_error
-function spip_mysql_error($serveur='') {
-	$connexion = &$GLOBALS['connexions'][$serveur ? $serveur : 0];
-	$link = $connexion['link'];
-	$e = ($link ? mysql_error($link) : mysql_error());
-	return  ($e ? $e . $connexion['last']:'');
+function spip_mysql_error($query='', $serveur='',$requeter=true) {
+	$link = $GLOBALS['connexions'][$serveur ? strtolower($serveur) : 0]['link'];
+	$s = $link ? mysql_error($link) : mysql_error();
+	if ($s) spip_log("$s - $query", 'mysql');
+	return $s;
 }
 
 // A transposer dans les portages
 // http://doc.spip.org/@spip_mysql_errno
-function spip_mysql_errno($serveur='') {
-	$connexion = &$GLOBALS['connexions'][$serveur ? $serveur : 0];
-	$link = $connexion['link'];
+function spip_mysql_errno($serveur='',$requeter=true) {
+	$link = $GLOBALS['connexions'][$serveur ? $serveur : 0]['link'];
 	$s = $link ? mysql_errno($link) : mysql_errno();
 	// 2006 MySQL server has gone away
 	// 2013 Lost connection to MySQL server during query
 	if (in_array($s, array(2006,2013)))
 		define('spip_interdire_cache', true);
+	if ($s) spip_log("Erreur mysql $s");
 	return $s;
 }
 
@@ -547,25 +558,30 @@ function spip_mysql_free($r, $serveur='',$requeter=true) {
 // http://doc.spip.org/@spip_mysql_insert
 function spip_mysql_insert($table, $champs, $valeurs, $desc='', $serveur='',$requeter=true) {
 
-	$connexion = &$GLOBALS['connexions'][$serveur ? $serveur : 0];
+	$connexion = &$GLOBALS['connexions'][$serveur ? strtolower($serveur) : 0];
 	$prefixe = $connexion['prefixe'];
 	$link = $connexion['link'];
 	$db = $connexion['db'];
 
 	if ($prefixe) $table = preg_replace('/^spip/', $prefixe, $table);
-
+	
+	$query ="INSERT INTO $table $champs VALUES $valeurs";
+	if (!$requeter) return $query;
+	
 	if (isset($_GET['var_profile'])) {
 		include_spip('public/tracer');
 		$t = trace_query_start();
 	} else $t = 0 ;
- 
-	$connexion['last'] = $query ="INSERT INTO $table $champs VALUES $valeurs";
+
+	$connexion['last'] = $query;
 #	spip_log($query);
 	if (mysql_query($query, $link))
 		$r = mysql_insert_id($link);
-	else $r = false;
-
-	return $t ? trace_query_end($query, $t, $r, $serveur) : $r;
+	else {
+	  if ($e = spip_mysql_errno($serveur))	// Log de l'erreur eventuelle
+		$e .= spip_mysql_error($query, $serveur); // et du fautif
+	}
+	return $t ? trace_query_end($query, $t, $r, $e, $serveur) : $r;
 
 	// return $r ? $r : (($r===0) ? -1 : 0); pb avec le multi-base.
 }
@@ -650,8 +666,10 @@ function spip_mysql_delete($table, $where='', $serveur='',$requeter=true) {
 			  calculer_mysql_expression('DELETE FROM', $table, ',')
 			. calculer_mysql_expression('WHERE', $where),
 			$serveur, $requeter);
+	if (!$requeter) return $res;
 	if ($res){
-		$link = $GLOBALS['connexions'][$serveur ? $serveur : 0]['link'];
+		$connexion = &$GLOBALS['connexions'][$serveur ? $serveur : 0];
+		$link = $connexion['link'];
 		return $link ? mysql_affected_rows($link) : mysql_affected_rows();
 	}
 	else
@@ -815,5 +833,34 @@ function spip_versions_mysql() {
 	return function_exists('mysql_query');
 }
 
+// Tester si mysql ne veut pas du nom de la base dans les requetes
+
+// http://doc.spip.org/@test_rappel_nom_base_mysql
+function test_rappel_nom_base_mysql($server_db)
+{
+	$GLOBALS['mysql_rappel_nom_base'] = true;
+	sql_delete('spip_meta', "nom='mysql_rappel_nom_base'", $server_db);
+	$ok = spip_query("INSERT INTO spip_meta (nom,valeur) VALUES ('mysql_rappel_nom_base', 'test')", $server_db);
+
+	if ($ok) {
+		sql_delete('spip_meta', "nom='mysql_rappel_nom_base'", $server_db);
+		return '';
+	} else {
+		$GLOBALS['mysql_rappel_nom_base'] = false;
+		return "\$GLOBALS['mysql_rappel_nom_base'] = false; ".
+		"/* echec de test_rappel_nom_base_mysql a l'installation. */\n";
+	}
+}
+
+// http://doc.spip.org/@test_sql_mode_mysql
+function test_sql_mode_mysql($server_db){
+	$res = sql_select("version() as v",'','','','','','',$server_db);
+	$row = sql_fetch($res,$server_db);
+	if (version_compare($row['v'],'5.0.0','>=')){
+		define('_MYSQL_SET_SQL_MODE',true);
+		return "define('_MYSQL_SET_SQL_MODE',true);\n";
+	}
+	return '';
+}
 
 ?>
