@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2011                                                *
+ *  Copyright (c) 2001-2012                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -1309,16 +1309,16 @@ function _sqlite_charger_version($version=''){
 function _sqlite_modifier_table($table, $colonne, $opt=array(), $serveur=''){
 
 	if (is_array($table)) {
-		$table_origine = array_shift(array_keys($table));
-		$table_destination = array_shift($table);
+		reset($table);
+		list($table_origine,$table_destination) = each($table);
 	} else {
 		$table_origine = $table_destination = $table;
 	}
 	// ne prend actuellement qu'un changement
 	// mais pourra etre adapte pour changer plus qu'une colonne a la fois
 	if (is_array($colonne)) {
-		$colonne_origine = array_shift(array_keys($colonne));
-		$colonne_destination = array_shift($colonne);
+		reset($colonne);
+		list($colonne_origine,$colonne_destination) = each($colonne);
 	} else {
 		$colonne_origine = $colonne_destination = $colonne;
 	}	
