@@ -1,5 +1,15 @@
 <?php
 
+if (!defined("_ECRIRE_INC_VERSION")) return;
+
+function compacte_ecrire_balise_script_dist($src){
+	return "<script type='text/javascript' src='$src'></script>";
+}
+function compacte_ecrire_balise_link_dist($src,$media=""){
+	return "<link rel='stylesheet'".($media?" media='$media'":"")." href='$src' type='text/css' />";
+}
+
+
 // http://doc.spip.org/@compacte_css
 function compacte_css ($contenu) {
 	// nettoyer la css de tout ce qui sert pas
@@ -7,8 +17,11 @@ function compacte_css ($contenu) {
 	$contenu = preg_replace(",\s(?=\s),Ums","",$contenu); // pas d'espaces consecutifs
 	$contenu = preg_replace("/\s?({|;|,|:)\s?/ms","$1",$contenu); // pas d'espaces dans les declarations css
 	$contenu = preg_replace("/\s}/ms","}",$contenu); // pas d'espaces dans les declarations css
-	$contenu = preg_replace(",#([0-9a-f])(\\1)([0-9a-f])(\\3)([0-9a-f])(\\5),i","#$1$3$5",$contenu); // passser les codes couleurs en 3 car si possible
-	$contenu = preg_replace(",([^{}]*){},Ums"," ",$contenu); // supprimer les declarations vides
+	// passser les codes couleurs en 3 car si possible
+	// uniquement si non precedees d'un [="'] ce qui indique qu'on est dans un filter(xx=#?...)
+	$contenu = preg_replace(";([:\s,(])#([0-9a-f])(\\2)([0-9a-f])(\\4)([0-9a-f])(\\6)(?=[^\w\-]);i","$1#$2$4$6",$contenu);
+	// supprimer les declarations vides
+	$contenu = preg_replace(",(^|})([^{}]*){},Ums","$1",$contenu);
 	$contenu = trim($contenu);
 
 	return $contenu;
@@ -51,6 +64,7 @@ function compacte_head_js($flux) {
 	$flux_nocomment = preg_replace(",<!--.*-->,Uims","",$flux);
 	foreach (extraire_balises($flux_nocomment,'script') as $s) {
 		if (extraire_attribut($s, 'type') === 'text/javascript'
+		AND is_null(extraire_attribut($s, 'id')) # script avec un id : pas touche
 		AND $src = extraire_attribut($s, 'src')
 		AND !strlen(strip_tags($s))
 		AND (
@@ -75,10 +89,11 @@ function compacte_head_js($flux) {
 	}
 
 	if (list($src,$comms) = filtre_cache_static($scripts,'js')){
+		$compacte_ecrire_balise_script = charger_fonction('compacte_ecrire_balise_script','');
 		$scripts = array_keys($scripts);
 		$flux = str_replace(reset($scripts),
-			$comms
-			."<script type='text/javascript' src='$src'></script>\n",$flux);
+			$comms .$compacte_ecrire_balise_script($src)."\n",
+			$flux);
 		$flux = str_replace($scripts,"",$flux);
 	}
 
@@ -118,6 +133,7 @@ function compacte_head_css($flux) {
 			)
 		)) {
 			$media = strval(extraire_attribut($s, 'media'));
+			if ($media==='') $media='all';
 			if ($r)
 				$css[$media][$s] = explode('&',
 					str_replace('&amp;', '&', $r[2]), 2);
@@ -131,10 +147,11 @@ function compacte_head_css($flux) {
 		// si plus d'une css pour ce media ou si c'est une css dynamique
 		if (count($s)>1 OR is_array(reset($s))){
 			if (list($src,$comms) = filtre_cache_static($s,'css')){
+				$compacte_ecrire_balise_link = charger_fonction('compacte_ecrire_balise_link','');
 				$s = array_keys($s);
 				$flux = str_replace(reset($s),
-					$comms
-					."<link rel='stylesheet'".($m?" media='$m'":"")." href='$src' type='text/css' />\n",$flux);
+								$comms . $compacte_ecrire_balise_link($src,$m)."\n",
+								$flux);
 				$flux = str_replace($s,"",$flux);
 			}
 		}
@@ -192,7 +209,7 @@ function filtre_cache_static($scripts,$type='js'){
 			}
 
 			// calcul du % de compactage
-			$pc = intval(1000*strlen($fichier)/$total)/10;
+			$pc = ($total?intval(1000*strlen($fichier)/$total)/10:0);
 			$comms = "compact [\n\t".join("\n\t", $comms)."\n] $pc%";
 			$fichier = "/* $comms */\n\n".$fichier;
 
