@@ -4,6 +4,9 @@
  * Licence GPL
  * Auteur Matthieu Marcillaud
  */
+
+if (!defined("_ECRIRE_INC_VERSION")) return;
+
 #define('PORTE_PLUME_PUBLIC', true);
 
 function porte_plume_autoriser($flux){return $flux;}
@@ -114,4 +117,9 @@ function porte_plume_affiche_milieu($flux){
 
 	return $flux;
 }
+
+function porte_plume_porte_plume_barre_pre_charger($flux){return $flux;}
+function porte_plume_porte_plume_barre_charger($flux){return $flux;}
+function porte_plume_porte_plume_lien_classe_vers_icone($flux){return $flux;}
+
 ?>
